@@ -1,11 +1,19 @@
 # -*- coding: utf-8 -*-
 from brewtils.models import Operation
 
-from beer_garden.api.http.base_handler import BaseHandler
+from beer_garden.api.authorization import Permissions
+from beer_garden.api.http.handlers import AuthorizationHandler
+from beer_garden.db.mongo.api import MongoParser
+from beer_garden.db.mongo.models import System
 from beer_garden.errors import EndpointRemovedException
 
+SYSTEM_CREATE = Permissions.SYSTEM_CREATE.value
+SYSTEM_READ = Permissions.SYSTEM_READ.value
+SYSTEM_UPDATE = Permissions.SYSTEM_UPDATE.value
+SYSTEM_DELETE = Permissions.SYSTEM_DELETE.value
 
-class CommandAPI(BaseHandler):
+
+class CommandAPI(AuthorizationHandler):
     async def get(self, system_id, command_name):
         """
         ---
@@ -33,6 +41,8 @@ class CommandAPI(BaseHandler):
         tags:
           - Commands
         """
+        _ = self.get_or_raise(System, SYSTEM_READ, id=system_id)
+
         response = await self.client(
             Operation(operation_type="COMMAND_READ", args=[system_id, command_name])
         )
@@ -40,7 +50,7 @@ class CommandAPI(BaseHandler):
         self.write(response)
 
 
-class CommandAPIOld(BaseHandler):
+class CommandAPIOld(AuthorizationHandler):
     async def get(self, command_id):
         """
         ---
@@ -72,7 +82,7 @@ class CommandAPIOld(BaseHandler):
         )
 
 
-class CommandListAPI(BaseHandler):
+class CommandListAPI(AuthorizationHandler):
     async def get(self):
         """
         ---
@@ -90,6 +100,13 @@ class CommandListAPI(BaseHandler):
         tags:
           - Deprecated
         """
-        response = await self.client(Operation(operation_type="COMMAND_READ_ALL"))
+        systems = self.permissioned_queryset(System, SYSTEM_READ)
+        commands = []
+
+        for system in systems:
+            commands.extend(system.commands)
+
+        response = MongoParser.serialize(commands, to_string=True)
+
         self.set_header("Content-Type", "application/json; charset=UTF-8")
         self.write(response)
