@@ -64,8 +64,6 @@ def load(args: Sequence[str], force: bool = False) -> None:
     config = Box(raw_config.to_dict(), default_box=True)
     if config.entry.http.url_prefix:
         config.entry.http.url_prefix = normalize(config.entry.http.url_prefix)
-    if config.event.brew_view.url_prefix:
-        config.event.brew_view.url_prefix = normalize(config.event.brew_view.url_prefix)
 
     _CONFIG = Box(config.to_dict())
 
@@ -757,6 +755,15 @@ _DB_SPEC = {
                     "previous_names": ["info_request_ttl"],
                     "alt_env_names": ["INFO_REQUEST_TTL"],
                 },
+                "in_progress": {
+                    "type": "int",
+                    "default": -1,
+                    "description": (
+                        "Number of minutes to wait for a request in CREATED or IN_PROGRESS"
+                        "to complete before considering timed out and marking as CANCELLED"
+                        "(negative number for never)"
+                    ),
+                },
                 "file": {
                     "type": "int",
                     "default": 15,
