@@ -9,8 +9,9 @@ The system service is responible for:
 """
 
 import copy
-
 import logging
+from typing import List, Sequence
+
 from brewtils.errors import (
     BrewtilsException,
     ModelValidationError,
@@ -19,7 +20,6 @@ from brewtils.errors import (
 )
 from brewtils.models import Command, Event, Events, Instance, System
 from brewtils.schemas import SystemSchema
-from typing import List, Sequence
 
 import beer_garden.config as config
 import beer_garden.db.api as db
@@ -124,6 +124,7 @@ def update_system(
 
         if (
             system.commands
+            and not config.get("plugin.allow_command_updates")
             and "dev" not in system.version
             and system.has_different_commands(brew_commands)
         ):
@@ -167,7 +168,7 @@ def update_system(
             if instance.name in instance_names:
                 raise ModelValidationError(
                     f"Unable to add Instance {instance} to System {system}: Duplicate "
-                    f"instance names"
+                    "instance names"
                 )
 
             updates["push_all__instances"].append(db.from_brewtils(instance))
@@ -285,7 +286,7 @@ def purge_system(
 
                 logger.warning(
                     f"Error while stopping instance {system}[{instance.name}]. "
-                    f"Force flag was specified so system delete will continue. "
+                    "Force flag was specified so system delete will continue. "
                     f"Underlying exception was: {ex}"
                 )
         else:
@@ -296,12 +297,12 @@ def purge_system(
                 except Exception as ex:
                     if not force:
                         raise RequestPublishException(
-                            f"Error attempting to publish stop message for "
+                            "Error attempting to publish stop message for "
                             f"{system}[{instance.name}"
                         ) from ex
 
                     logger.warning(
-                        f"Error while publishing stop message for "
+                        "Error while publishing stop message for "
                         f"{system}[{instance.name}]. Force flag was specified so "
                         f"system delete will continue. Underlying exception was: {ex}"
                     )
